@@ -28,7 +28,10 @@ class Translatable(object):
 
         manager = self.__translatable__['manager']
         if manager.option(self, 'get_locale_fallback'):
-            return manager.option(self, 'default_locale')
+            default_locale = manager.option(self, 'default_locale')
+            if callable(default_locale):
+                default_locale = default_locale()
+            return default_locale
 
     @hybrid_property
     def current_translation(self):
