@@ -1,3 +1,5 @@
+import sqlalchemy as sa
+from sqlalchemy_i18n import Translatable
 from tests import TestCase
 
 
@@ -84,3 +86,41 @@ class TestTranslatableModel(TestCase):
 
             assert article.current_translation == article._translation_fi
             article._translation_fi
+
+
+class TestCurrentTranslation(TestCase):
+    def create_models(self):
+        class Locale(object):
+            def __init__(self, value):
+                self.value = value
+
+            def __unicode__(self):
+                return self.value
+
+        class Article(self.Model, Translatable):
+            __tablename__ = 'article'
+            __translated_columns__ = [
+                sa.Column('name', sa.Unicode(255), nullable=False),
+                sa.Column('content', sa.UnicodeText)
+            ]
+            __translatable__ = {
+                'base_classes': (self.Model, ),
+                'locales': ['en', 'fi'],
+                'default_locale': 'en'
+            }
+
+            def get_locale(self):
+                return Locale('en')
+
+            id = sa.Column(sa.Integer, autoincrement=True, primary_key=True)
+            description = sa.Column(sa.UnicodeText)
+
+        self.Article = Article
+
+    def test_converts_locale_object_to_unicode(self):
+        article = self.Article()
+        article.name = u'Some article'
+        assert article.name == u'Some article'
+
+    def test_current_translation_as_class_property(self):
+        assert self.Article.current_translation
